==> forestry_1.9-5.0.0.85-sources.jar: forestry/core/inventory/InventoryAdapterRestricted.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.inventory;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumFacing;

import forestry.core.access.IAccessHandler;
import forestry.core.config.Constants;

public class InventoryAdapterRestricted extends InventoryAdapter {
	private final IAccessHandler accessHandler;

	public InventoryAdapterRestricted(int size, String name, IAccessHandler accessHandler) {
		super(size, name);
		this.accessHandler = accessHandler;
	}

	public InventoryAdapterRestricted(int size, String name, int stackLimit, IAccessHandler accessHandler) {
		super(size, name, stackLimit);
		this.accessHandler = accessHandler;
	}

	@Override
	public final boolean isUseableByPlayer(EntityPlayer player) {
		return accessHandler.allowsViewing(player);
	}

	@Override
	public boolean isItemValidForSlot(int slotIndex, ItemStack itemStack) {
		if (itemStack == null || !accessHandler.allowsPipeConnections()) {
			return false;
		}

		return canSlotAccept(slotIndex, itemStack);
	}
	
	@Override
	public int[] getSlotsForFace(EnumFacing side) {
		if (!accessHandler.allowsPipeConnections()) {
			return Constants.SLOTS_NONE;
		}
		return super.getSlotsForFace(side);
	}

	@Override
	public final boolean canInsertItem(int slotIndex, ItemStack itemStack, EnumFacing side) {
		if (itemStack == null || !accessHandler.allowsPipeConnections()) {
			return false;
		}
		return isItemValidForSlot(slotIndex, itemStack);
	}

	@Override
	public boolean canExtractItem(int slotIndex, ItemStack itemStack, EnumFacing side) {
		return itemStack != null && accessHandler.allowsPipeConnections();
	}
}

==> forestry_1.10.2-5.1.9.191-sources.jar: forestry/core/inventory/InventoryAdapterRestricted.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.inventory;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumFacing;

import forestry.core.access.IAccessHandler;
import forestry.core.config.Constants;

public class InventoryAdapterRestricted extends InventoryAdapter {
	private final IAccessHandler accessHandler;

	public InventoryAdapterRestricted(int size, String name, IAccessHandler accessHandler) {
		super(size, name);
		this.accessHandler = accessHandler;
	}

	public InventoryAdapterRestricted(int size, String name, int stackLimit, IAccessHandler accessHandler) {
		super(size, name, stackLimit);
		this.accessHandler = accessHandler;
	}

	@Override
	public final boolean func_70300_a(EntityPlayer player) {
		return accessHandler.allowsViewing(player);
	}

	@Override
	public boolean func_94041_b(int slotIndex, ItemStack itemStack) {
		if (itemStack == null || !accessHandler.allowsPipeConnections()) {
			return false;
		}

		return canSlotAccept(slotIndex, itemStack);
	}
	
	@Override
	public int[] func_180463_a(EnumFacing side) {
		if (!accessHandler.allowsPipeConnections()) {
			return Constants.SLOTS_NONE;
		}
		return super.func_180463_a(side);
	}

	@Override
	public final boolean func_180462_a(int slotIndex, ItemStack itemStack, EnumFacing side) {
		if (itemStack == null || !accessHandler.allowsPipeConnections()) {
			return false;
		}
		return func_94041_b(slotIndex, itemStack);
	}

	@Override
	public boolean func_180461_b(int slotIndex, ItemStack itemStack, EnumFacing side) {
		return itemStack != null && accessHandler.allowsPipeConnections();
	}
}
